Welcome to UC Santa Barbara
Author: UCSB Office of Public Affairs
Description: The UNIVERSITY OF CALIFORNIA, SANTA BARBARA home page, portal to UCSB academics and research, plus SEARCH UTILITIES to find your way around the domain.
Keywords: Santa Barbara, Santa Barbara, Santa Barbara, Santa, Barbara, SB, S.B., SantaBarbara, UC Santa Barbara, UCSB, University of California Santa Barbara, university, higher education, major, degree, undergraduate, graduate, teaching, academics, research, Henry T. Yang, excellence, gauchos

HOME INDEX: A B C D E F G H I J K L M N O P Q R S T U V W X Y Z # PEOPLE | SEARCH
|  | Weather |
| 63ºF / 17ºC |
Alien Invasion UCSB scientists Tom Dudley and Adam Lambert are working with teachers and students from the Fillmore Unified School District to eradicate the reed Arundo donax as part of an effort to restore the Santa Clara River to its natural state.
Scientists Issue a Midterm Report on Ocean Management Strategies
Coastal Commission Approves Long Range Development Plan
UCSB Geography Professor Named Fellow of AAAS Science Organization
Trustees’ Committee on Isla Vista Strategies Publishes Report
UCSB Inaugurates New Program for Undergrads in Museum Studies
UCSB Reads “Orange Is the New Black,” the best-selling memoir by Piper Kerman who chronicles her year in a federal women’s prison, is this year’s selection for UCSB Reads. The book is the basis for the popular Netflix series.
ALL CAMPUS NEWS
Axiom, the fall dance concert from UCSB Dance, features six new choreographic works by students, as well as pieces from faculty and guest artists, Dec. 12-13.
Coal Oil Point Tour, free, open to the public and led by a trained guide, Dec. 6.
Danú, traditional Irish band, in "A Christmas Gathering," Dec. 12.
Arte Intimo, Arte Publico, the works of muralist Judy Baca, through Dec. 19.
ALL EVENTS
Google+